@@ -4,7 +4,7 @@ use warnings;
 package Util::H2O::More;
 use parent q/Exporter/;
 
-our $VERSION = q{0.0.8};
+our $VERSION = q{0.0.9};
 
 our @EXPORT_OK = (qw/baptise opt2h2o h2o o2h/);
 
@@ -213,7 +213,7 @@ without having more than one list. E.g.,
     use Getopt::Long qw//;
     my @opts = (qw/option1=s options2=s@ option3 option4=i o5|option5=s/);
     my $o = h2o {}, opt2h2o(@opts);
-    Getopt::Long::GetOptionsFromArray( @ARGV, $o, @opts );
+    Getopt::Long::GetOptionsFromArray( \@ARGV, $o, @opts ); # Note, @ARGV is passed by reference
     
     # now options are all available as accessors, e.g.:
     if ($o->option3) {
@@ -227,7 +227,8 @@ will work perfectly well with C<baptise> and friends.
     use Getopt::Long qw//;
     my @opts = (qw/option1=s options2=s@ option3 option4=i o5|option5=s/);
     my $o = h2o { option1 => q{foo} }, opt2h2o(@opts);
-    Getopt::Long::GetOptionsFromArray( \@ARGV, $o, @opts );
+    Getopt::Long::GetOptionsFromArray( \@ARGV, $o, @opts ); # Note, @ARGV is passed by reference 
+
     # ...
     # now $o can be used to query all possible options, even if they were
     # never passed at the commandline 
@@ -243,11 +244,24 @@ e.g., when one is dealing with an ad hoc object that then needs to be
 sent as a serialzied JSON string. It's convenient to be able to get
 the un<bless>'d data structure most JSON encoding methods are expecting.
 
-Implementation note:
+B<Implementation note:>
 
 Access to C<Util::H2O::o2h>, but adjusts $Util::H2O::_PACKAGE_REGEX to
 accept package names that are generated by C<Util::H2O::More::baptise>.
 
+B<Historical Note:>
+
+C<Util::H2O::More::o2h> preceded C<Util::H2O::o2h>, and the author
+of the latter added it after seeing it's usefulness in cases where
+the ability to get a pure C<HASH> reference after having I<objectified>
+was useful. A good example is the standard dislike C<JSON> modules'
+C<encode_json> method implementations have for blessed references;
+this also affects environments like L<Dancer2> or L<Mojo> that
+employ automatic serialization steps beyond route handlers. Returning
+a blessed reference would cause the underlying serialization routines
+to warn or C<die> without using C<o2h> to return a pure C<HASH>
+reference.
+
 =item C<baptise_deeply, $hash_ref, $pkg, LIST>
 
 This has been removed.
